@@ -4,6 +4,7 @@
 #
 
 from pyparsing import Word, Optional, OneOrMore, Group, ParseException, Regex
+from pyparsing import alphas
 
 atomicWeight = {
     "O"  : 15.9994,
@@ -30,7 +31,9 @@ digits = "0123456789"
 element = Regex("A[cglmrstu]|B[aehikr]?|C[adeflmorsu]?|D[bsy]|"
                 "E[rsu]|F[emr]?|G[ade]|H[efgos]?|I[nr]?|Kr?|L[airu]|"
                 "M[dgnot]|N[abdeiop]?|Os?|P[abdmortu]?|R[abefghnu]|"
-                "S[bcegimnr]?|T[abcehilm]|Uu[bhopqst]|U|V|W|Xe|Yb?|Z[nr]")
+                "S[bcegimnr]?|T[abcehilm]|U(u[bhopqst])?|V|W|Xe|Yb?|Z[nr]")
+
+element = Word( alphas.upper(), alphas.lower(), max=2)
 elementRef = Group( element + Optional( Word( digits ), default="1" ) )
 formula = OneOrMore( elementRef )
 
@@ -41,8 +44,7 @@ test( formula, "NaCl", fn )
 print
 
 # Version 2 - access parsed items by field name
-elementRef = Group( element.setResultsName("symbol") + \
-                Optional( Word( digits ), default="1" ).setResultsName("qty") )
+elementRef = Group( element("symbol") + Optional( Word( digits ), default="1" )("qty") )
 formula = OneOrMore( elementRef )
 
 fn = lambda elemList : sum( [ atomicWeight[elem.symbol]*int(elem.qty) for elem in elemList ] )
@@ -53,8 +55,7 @@ print
 
 # Version 3 - convert integers during parsing process
 integer = Word( digits ).setParseAction(lambda t:int(t[0]))
-elementRef = Group( element.setResultsName("symbol") + \
-                Optional( integer, default=1 ).setResultsName("qty") )
+elementRef = Group( element("symbol") + Optional( integer, default=1 )("qty") )
 formula = OneOrMore( elementRef )
 
 fn = lambda elemList : sum( [ atomicWeight[elem.symbol]*elem.qty for elem in elemList ] )
